
"""
igesture.pyx
"""

cdef extern from "igesturelib.h":

	cdef int igesturelib_init(int hwnd)
	cdef int igesturelib_processframes()
	cdef int igesturelib_numdevices()
	ctypedef int (FingerCallback)(int devnum, int fingnum, int event, float x, float y, float prox)
	cdef int igesturelib_setcallback(FingerCallback *callback)
	cdef float igesturelib_width(int d)
	cdef float igesturelib_height(int d)


import win32con
import sys
import ctypes
import time
from threading import Timer

global Gigesture

cdef int local_callback(int devnum, int fingnum, int event, float x, float y, float prox):
	Gigesture.callback(devnum,fingnum,event,x,y,prox)

cdef class device:

	cdef int done
	cdef object callback_method

	def __new__(self):
		global Gigesture
		Gigesture = self
		self.done = 0
		self.callback_method = 0
	
	def init(self, hwnd):
		n = igesturelib_init(hwnd)
		igesturelib_setcallback(local_callback)
		return n

	def setcallback(self, f):
		self.callback_method = f

	def callback(self, devnum, fingnum, event, x, y, prox):
		if self.callback_method != 0:
			self.callback_method(devnum,fingnum,event,x,y,prox)
		else:
			print "No callback_method set, d=%d f=%d e=%d\n" % (devnum,fingnum,event)

	def start_callbacks(self):
		import thread
		self.done = 0
		thread.start_new_thread(self.task_processframes,())

	def stop_callbacks(self):
		print("TRYING TO STOP MONITOR, setting self.done")
		self.done = 1

	def processframes(self):
		igesturelib_processframes()

	def numdevices(self):
		return igesturelib_numdevices()

	def device_width(self,dev):
		return igesturelib_width(dev)

	def device_height(self,dev):
		return igesturelib_height(dev)

	def task_processframes(self):
		while not self.done:
			try:
				t = Timer(0.01,self.processframes)
				t.start()
				# I'm not sure this join() actually works.
				# It may be the timeout that really does it.
				t.join(0.01)
			except:
				print sys.exc_info()

